@@ -54,6 +54,8 @@
 #define C_DOMAIN		"\x06""domain"
 #define C_DS_PUSH		"\x07""ds-push"
 #define C_ECS			"\x12""edns-client-subnet"
+#define C_EXPIRE_MAX_INTERVAL	"\x13""expire-max-interval"
+#define C_EXPIRE_MIN_INTERVAL	"\x13""expire-min-interval"
 #define C_FILE			"\x04""file"
 #define C_GLOBAL_MODULE		"\x0D""global-module"
 #define C_ID			"\x02""id"
@@ -96,6 +98,8 @@
 #define C_REFRESH_MAX_INTERVAL	"\x14""refresh-max-interval"
 #define C_REFRESH_MIN_INTERVAL	"\x14""refresh-min-interval"
 #define C_REPRO_SIGNING		"\x14""reproducible-signing"
+#define C_RETRY_MAX_INTERVAL	"\x12""retry-max-interval"
+#define C_RETRY_MIN_INTERVAL	"\x12""retry-min-interval"
 #define C_RMT			"\x06""remote"
 #define C_RMT_POOL_LIMIT	"\x11""remote-pool-limit"
 #define C_RMT_POOL_TIMEOUT	"\x13""remote-pool-timeout"
