@@ -39,6 +39,7 @@
 #include "contrib/files.h"
 #include "contrib/string.h"
 #include "contrib/strtonum.h"
+#include "contrib/openbsd/strlcat.h"
 #include "contrib/ucw/lists.h"
 #include "libzscanner/scanner.h"
 
@@ -305,6 +306,59 @@ static int zone_status(zone_t *zone, ctl_args_t *args)
 		}
 	}
 
+	if (MATCH_OR_FILTER(args, CTL_FILTER_STATUS_CATALOG)) {
+		char buf[1 + KNOT_DNAME_TXT_MAXLEN + 1 + CATALOG_GROUP_MAXLEN + 1] = "";
+		data[KNOT_CTL_IDX_TYPE] = "catalog";
+		data[KNOT_CTL_IDX_DATA] = buf;
+
+		if (zone->flags & ZONE_IS_CAT_MEMBER) {
+			const knot_dname_t *catz;
+			const char *group;
+			void *to_free;
+			ret = catalog_get_catz(zone->catalog, zone->name,
+			                       &catz, &group, &to_free);
+			if (ret == KNOT_EOK) {
+				if (knot_dname_to_str(buf, catz, sizeof(buf)) == NULL) {
+					buf[0] = '\0';
+				}
+				if (group[0] != '\0') {
+					size_t idx = strlcat(buf, "#", sizeof(buf));
+					(void)strlcat(buf + idx, group, sizeof(buf) - idx);
+				}
+				free(to_free);
+			}
+		} else {
+			conf_val_t val = conf_zone_get(conf(), C_CATALOG_ROLE, zone->name);
+			switch (conf_opt(&val)) {
+			case CATALOG_ROLE_INTERPRET:
+				data[KNOT_CTL_IDX_DATA] = "interpret";
+				break;
+			case CATALOG_ROLE_GENERATE:
+				data[KNOT_CTL_IDX_DATA] = "generate";
+				break;
+			case CATALOG_ROLE_MEMBER:
+				buf[0] = '@';
+				val = conf_zone_get(conf(), C_CATALOG_ZONE, zone->name);
+				if (knot_dname_to_str(buf + 1, conf_dname(&val), sizeof(buf) - 1) == NULL) {
+					buf[1] = '\0';
+				}
+				val = conf_zone_get(conf(), C_CATALOG_GROUP, zone->name);
+				if (val.code == KNOT_EOK) {
+					size_t idx = strlcat(buf, "#", sizeof(buf));
+					(void)strlcat(buf + idx, conf_str(&val), sizeof(buf) - idx);
+				}
+				break;
+			default:
+				data[KNOT_CTL_IDX_DATA] = "none";
+			}
+		}
+
+		ret = knot_ctl_send(args->ctl, type, &data);
+		if (ret != KNOT_EOK) {
+			return ret;
+		}
+	}
+
 	if (MATCH_OR_FILTER(args, CTL_FILTER_STATUS_EVENTS)) {
 		for (zone_event_type_t i = 0; i < ZONE_EVENT_COUNT; i++) {
 			// Events not worth showing or used elsewhere.
@@ -312,11 +366,6 @@ static int zone_status(zone_t *zone, ctl_args_t *args)
 				continue;
 			}
 
-			// Skip events affected by freeze.
-			if (ufrozen && ufreeze_applies(i)) {
-				continue;
-			}
-
 			data[KNOT_CTL_IDX_TYPE] = zone_events_get_name(i);
 			time_t ev_time = zone_events_get_time(zone, i);
 			if (zone->events.running && zone->events.type == i) {
@@ -324,7 +373,8 @@ static int zone_status(zone_t *zone, ctl_args_t *args)
 			} else if (ev_time <= 0) {
 				ret = snprintf(buff, sizeof(buff), "not scheduled");
 			} else if (ev_time <= time(NULL)) {
-				ret = snprintf(buff, sizeof(buff), "pending");
+				bool frozen = ufrozen && ufreeze_applies(i);
+				ret = snprintf(buff, sizeof(buff), frozen ? "frozen" : "pending");
 			} else {
 				ret = knot_time_print(TIME_PRINT_HUMAN_MIXED,
 				                      ev_time, buff, sizeof(buff));
