@@ -1,4 +1,4 @@
-/*  Copyright (C) 2019 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2021 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -242,6 +242,9 @@ void serialize_deinit(serialize_ctx_t *ctx)
 	if (ctx->it.node != NULL) {
 		changeset_iter_clear(&ctx->it);
 	}
+	if (ctx->zit.tree != NULL) {
+		zone_tree_it_free(&ctx->zit);
+	}
 	free(ctx);
 }
 
