@@ -1,4 +1,4 @@
-/*  Copyright (C) 2021 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2022 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -106,6 +106,7 @@ static zone_t *create_zone_reload(conf_t *conf, const knot_dname_t *name,
 		conf_updated = true;
 	}
 
+	zone->events.ufrozen = old_zone->events.ufrozen;
 	if ((zone_file_updated(conf, old_zone, name) || conf_updated) && !zone_expired(zone)) {
 		replan_load_updated(zone, old_zone);
 	} else {
@@ -172,6 +173,7 @@ static zone_t *create_zone_new(conf_t *conf, const knot_dname_t *name,
 		if (ret != KNOT_EOK) {
 			log_error("failed to open catalog database (%s)", knot_strerror(ret));
 		}
+		zone_set_flag(zone, ZONE_IS_CATALOG);
 	}
 
 	if (zone_expired(zone)) {
@@ -337,11 +339,17 @@ typedef struct {
 } reuse_cold_zone_ctx_t;
 
 static int reuse_cold_zone_cb(const knot_dname_t *member, _unused_ const knot_dname_t *owner,
-                              _unused_ const knot_dname_t *catz, _unused_ const char *group,
+                              const knot_dname_t *catz, _unused_ const char *group,
                               void *ctx)
 {
 	reuse_cold_zone_ctx_t *rcz = ctx;
 
+	zone_t *catz_z = knot_zonedb_find(rcz->zonedb, catz);
+	if (catz_z == NULL || !(catz_z->flags & ZONE_IS_CATALOG)) {
+		log_zone_warning(member, "orphaned catalog member zone, ignoring");
+		return KNOT_EOK;
+	}
+
 	zone_t *zone = reuse_cold_zone(member, rcz->server, rcz->conf);
 	if (zone == NULL) {
 		return KNOT_ENOMEM;
