@@ -1,4 +1,4 @@
-/*  Copyright (C) 2020 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2021 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -79,3 +79,15 @@ const knot_lookup_t knot_dnssec_alg_names[] = {
 	{ KNOT_DNSSEC_ALG_PRIVATEOID,         "PRIVATEOID" },
 	{ 0, NULL }
 };
+
+_public_
+const knot_lookup_t knot_svcb_param_names[] = {
+	{ KNOT_SVCB_PARAM_MANDATORY, "mandatory" },
+	{ KNOT_SVCB_PARAM_ALPN,      "alpn" },
+	{ KNOT_SVCB_PARAM_NDALPN,    "no-default-alpn" },
+	{ KNOT_SVCB_PARAM_PORT,      "port" },
+	{ KNOT_SVCB_PARAM_IPV4HINT,  "ipv4hint" },
+	{ KNOT_SVCB_PARAM_ECH,       "ech" },
+	{ KNOT_SVCB_PARAM_IPV6HINT,  "ipv6hint" },
+	{ 0, NULL }
+};
