@@ -33,6 +33,10 @@
 #include "contrib/base64.h"
 #include "libknot/errcode.h"
 
+const gnutls_datum_t dot_alpn = {
+	(unsigned char *)"dot", 3
+};
+
 void tls_params_init(tls_params_t *params)
 {
 	if (params == NULL) {
