@@ -1,4 +1,4 @@
-/*  Copyright (C) 2019 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2021 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -97,7 +97,7 @@ static char *get_id_name(const char *section)
 	knot_ctl_data_t reply;
 
 	// Try to get the first group item (possible id).
-	if (set_ctl(&ctl, desc, &params) != KNOT_EOK ||
+	if (set_ctl(&ctl, params.socket, DEFAULT_CTL_TIMEOUT_MS, desc) != KNOT_EOK ||
 	    knot_ctl_send(ctl, KNOT_CTL_TYPE_DATA, &query) != KNOT_EOK ||
 	    knot_ctl_send(ctl, KNOT_CTL_TYPE_BLOCK, NULL) != KNOT_EOK ||
 	    knot_ctl_receive(ctl, &type, &reply) != KNOT_EOK ||
@@ -140,7 +140,7 @@ static void id_lookup(EditLine *el, const char *str, size_t str_len,
 	lookup_t lookup;
 	knot_ctl_t *ctl = NULL;
 
-	if (set_ctl(&ctl, desc, &params) != KNOT_EOK ||
+	if (set_ctl(&ctl, params.socket, DEFAULT_CTL_TIMEOUT_MS, desc) != KNOT_EOK ||
 	    knot_ctl_send(ctl, KNOT_CTL_TYPE_DATA, &query) != KNOT_EOK ||
 	    knot_ctl_send(ctl, KNOT_CTL_TYPE_BLOCK, NULL) != KNOT_EOK ||
 	    lookup_init(&lookup) != KNOT_EOK) {
@@ -195,7 +195,7 @@ static void list_lookup(EditLine *el, const char *section, const char *item)
 	lookup_t lookup;
 	knot_ctl_t *ctl = NULL;
 
-	if (set_ctl(&ctl, desc, &params) != KNOT_EOK ||
+	if (set_ctl(&ctl, params.socket, DEFAULT_CTL_TIMEOUT_MS, desc) != KNOT_EOK ||
 	    knot_ctl_send(ctl, KNOT_CTL_TYPE_DATA, &query) != KNOT_EOK ||
 	    knot_ctl_send(ctl, KNOT_CTL_TYPE_BLOCK, NULL) != KNOT_EOK ||
 	    lookup_init(&lookup) != KNOT_EOK) {
@@ -392,6 +392,8 @@ int interactive_loop(params_t *process_params)
 	el_set(el, EL_SIGNAL, 1);
 	el_source(el, NULL);
 
+	// Warning: these two el_sets()'s always leak -- in libedit2 library!
+	// For more details see this commit's message.
 	el_set(el, EL_ADDFN, PROGRAM_NAME"-complete",
 	       "Perform "PROGRAM_NAME" completion.", complete);
 	el_set(el, EL_BIND, "^I",  PROGRAM_NAME"-complete", NULL);
